/****************************************************************************
**
** DCOP Stub Definition created by dcopidl2cpp from kshutdowniface.kidl
**
** WARNING! All changes made in this file will be lost!
**
*****************************************************************************/

#ifndef __KSHUTDOWNIFACE_STUB__
#define __KSHUTDOWNIFACE_STUB__

#include <dcopstub.h>
#include <dcopobject.h>


class KShutdownIface_stub : virtual public DCOPStub
{
public:
    KShutdownIface_stub( const QCString& app, const QCString& id );
    KShutdownIface_stub( DCOPClient* client, const QCString& app, const QCString& id );
    explicit KShutdownIface_stub( const DCOPRef& ref );
    virtual ASYNC cancel();
    virtual bool shutDown();
    virtual bool shutdown();
    virtual bool reboot();
    virtual bool lockScreen();
    virtual bool logout();
    virtual ASYNC configure();
    virtual QString getStatusInfo();
    virtual ASYNC makeVisible();
    virtual ASYNC setTestMode( bool yes );
protected:
    KShutdownIface_stub() : DCOPStub( never_use ) {};
};


#endif
